@@ -126,7 +126,7 @@ function initLevel() {
             price += cents
         }
 
-        var priceText = Number(price).toLocaleCurrencyString(Qt.locale(locale))
+        var priceText = Core.convertNumberToLocaleCurrencyString(Number(price), locale)
         if(!centsMode) {
             // Strip floating part
             priceText = priceText.replace((/[,.]00/), "")
@@ -164,7 +164,7 @@ function initLevel() {
         for(var i=0; i < tuxMoney.length; i++)
             tuxTotal += tuxMoney[i].val
 
-        var priceText = Number(tuxTotal).toLocaleCurrencyString(Qt.locale(locale))
+        var priceText = Core.convertNumberToLocaleCurrencyString(Number(tuxTotal), locale)
         if(!centsMode) {
             // Strip floating part
             priceText = priceText.replace((/.00/), "")
