@@ -16,63 +16,63 @@ var items
 var url = "qrc:/gcompris/src/activities/photo_hunter/resource/"
 
 
-
+//coordinates are normalized (0 to 1) position/size values of items relative to original image size
 var dataset = [
             {
-                "coordinates": [{x: 12, y:5, r: 0.5, w: 1.25, h: 1.25},
-                    {x: 75, y:1170, r: 0.5, w: 0.35, h: 0.4},
-                    {x: 343, y:1375, r: 1, w: 0.9, h: 0.9}]
+                "coordinates": [{x: 0.037, y: 0.011, w: 0.138, h: 0.138},
+                    {x: 0.064, y: 0.707, w: 0.031, h: 0.032},
+                    {x: 0.278, y: 0.816, w: 0.104, h: 0.072}]
             },
             {
-                "coordinates": [{x: 949.5, y:268.5, r: 0.7, w: 0.85, h: 0.92},
-                    {x: 915, y:1555, r: 0.7, w: 0.75, h: 0.6},
-                    {x: 510, y:1300, r: 1.7, w: 1.25, h: 2}]
+                "coordinates": [{x: 0.792, y: 0.16, w: 0.082, h: 0.093},
+                    {x: 0.77, y: 0.906, w: 0.083, h: 0.06},
+                    {x: 0.417, y: 0.759, w: 0.128, h: 0.206}]
             },
             {
-                "coordinates": [{x: 800, y:40, r: 1.8, w: 2.6, h: 1},
-                    {x: 593, y:1450, r: 0.5, w: 0.8, h: 0.65}]
+                "coordinates": [{x: 0.7, y: 0.09, w: 0.214, h: 0.072},
+                    {x: 0.487, y: 0.856, w: 0.134, h: 0.055}]
             },
             {
-                "coordinates": [{x: 975, y:140, r: 0.2, w: 0.3, h: 0.3},
-                    {x: 680, y:720, r: 0.25, w: 0.3, h: 0.4},
-                    {x: 570, y:1580, r: 1.3, w: 1.3, h: 0.6},
-                    {x: 220, y:650, r: 0.7, w: 1, h: 1}]
+                "coordinates": [{x: 0.786, y: 0.093, w: 0.059, h: 0.028},
+                    {x: 0.553, y: 0.477, w: 0.017, h: 0.044},
+                    {x: 0.406, y: 0.929, w: 0.158, h: 0.046},
+                    {x: 0.173, y: 0.388, w: 0.087, h: 0.073}]
             },
             {
-                "coordinates": [{x: 540, y:200, r: 0.25, w: 0.5, h: 0.5},
-                    {x: 335, y:1228, r: 1, w: 0.25, h: 0.25},
-                    {x: 600, y:1150, r: 0.25, w: 0.5, h: 0.5},
-                    {x: 680, y:1330, r: 1, w: 1.3, h: 0.6}]
+                "coordinates": [{x: 0.456, y: 0.143, w: 0.038, h: 0.033},
+                    {x: 0.28, y: 0.72, w: 0.022, h: 0.023},
+                    {x: 0.482, y: 0.686, w: 0.077, h: 0.039},
+                    {x: 0.599, y: 0.786, w: 0.139, h: 0.074}]
             },
             {
-                "coordinates": [{x: 130, y: 450, r: 1, w: 1.5, h: 1.5},
-                    {x: 825, y: 234, r: 0.7, w: 0.8, h: 0.8},
-                    {x: 950, y: 1450, r: 0.7, w: 1, h: 1}]
+                "coordinates": [{x: 0.14, y: 0.291, w: 0.139, h: 0.14},
+                    {x: 0.659, y: 0.084, w: 0.126, h: 0.082},
+                    {x: 0.741, y: 0.872, w: 0.128, h: 0.072}]
             },
             {
-                "coordinates": [{x: 70, y: 600, r: 1, w: 1.6, h: 0.8},
-                    {x: 950, y: 1120, r: 1, w: 1.3, h: 0.45},
-                    {x: 380, y: 815, r: 1, w: 0.3, h: 0.41}]
+                "coordinates": [{x: 0.049, y: 0.265, w: 0.155, h: 0.05},
+                    {x: 0.507, y: 0.739, w: 0.134, h: 0.049},
+                    {x: 0.766, y: 0.405, w: 0.038, h: 0.039}]
             },
             {
-                "coordinates": [{x: 445, y: 1135, r: 0.5, w: 0.8, h: 0.3},
-                    {x: 17, y: 1300, r: 0.5, w: 0.6, h: 0.6},
-                    {x: 782, y: 670, r: 0.75, w: 0.8, h: 0.8},
-                    {x: 98, y: 1002, r: 0.5, w: 0.85, h: 0.3},
-                    {x: 527, y: 415, r: 0.15, w: 0.178, h: 0.25},
-                    {x: 337, y: 725, r: 0.15, w: 0.25, h: 0.25}]
+                "coordinates": [{x: 0.364, y: 0.665, w: 0.088, h: 0.029},
+                    {x: 0.077, y: 0.834, w: 0.047, h: 0.058},
+                    {x: 0.663, y: 0.395, w: 0.073, h: 0.054},
+                    {x: 0.133, y: 0.503, w: 0.047, h: 0.071},
+                    {x: 0.378, y: 0.239, w: 0.015, h: 0.022},
+                    {x: 0.439, y: 0.48, w: 0.022, h: 0.015}]
             },
             {
                 "coordinates":
-                    [{x: 275, y: 345, r: 0.15, w: 0.25, h: 0.25},
-                    {x: 1013, y: 1322, r: 0.15, w: 0.25, h: 0.25},
-                    {x: 595, y: 1530, r: 0.7, w: 1, h: 0.15}]
+                    [{x: 0.096, y: 0.157, w: 0.02, h: 0.017},
+                    {x: 0.9, y: 0.891, w: 0.018, h: 0.011},
+                    {x: 0.497, y: 0.899, w: 0.098, h: 0.014}]
             },
             {
-                "coordinates": [{x: 565, y:1120, r: 0.35, w: 0.6, h: 0.55},
-                    {x: 595, y:1500, r: 0.35, w: 0.6, h: 0.55},
-                    {x: 680, y:433, r: 0.5, w: 0.6, h: 0.8},
-                    {x: 760, y:971, r: 0.5, w: 0.35, h: 0.6}]
+                "coordinates": [{x: 0.294, y: 0.86, w: 0.106, h: 0.048},
+                    {x: 0.032, y: 0.146, w: 0.052, h: 0.022},
+                    {x: 0.561, y: 0.25, w: 0.075, h: 0.087},
+                    {x: 0.621, y: 0.559, w: 0.056, h: 0.074}]
             }
         ]
 
