@@ -9,8 +9,7 @@
  *   SPDX-License-Identifier: GPL-3.0-or-later
  */
 .pragma library
-.import QtQuick 2.9 as Quick
-
+.import QtQuick 2.12 as Quick
 var url = "qrc:/gcompris/src/activities/target/resource/"
 
 var levels
@@ -68,3 +67,12 @@ function previousLevel() {
     }
     initLevel();
 }
+
+function checkAnswer() {
+    if(items.targetItem.scoreTotal.toString() === items.userEntry.text) {
+        items.bonus.good("flower")
+        items.inputLocked = true
+    }
+    else
+        items.bonus.bad("flower")
+}
