@@ -14,17 +14,12 @@
 #include "ApplicationInfo.h"
 
 #include <QtQml>
-#include <QtMath>
-#include <QUrl>
-#include <QUrlQuery>
 #include <QGuiApplication>
 #include <QScreen>
 #include <QLocale>
 #include <QQuickWindow>
-#include <QStandardPaths>
 #include <QSensor>
 
-#include <qmath.h>
 #include <QDebug>
 
 #include <QFontDatabase>
@@ -118,7 +113,7 @@ void ApplicationInfo::setApplicationWidth(const int newWidth)
 {
     if (newWidth != m_applicationWidth) {
         m_applicationWidth = newWidth;
-        emit applicationWidthChanged();
+        Q_EMIT applicationWidthChanged();
     }
 }
 
@@ -207,7 +202,7 @@ void ApplicationInfo::setIsPortraitMode(const bool newMode)
 {
     if (m_isPortraitMode != newMode) {
         m_isPortraitMode = newMode;
-        emit portraitModeChanged();
+        Q_EMIT portraitModeChanged();
     }
 }
 
@@ -243,7 +238,8 @@ void ApplicationInfo::setBox2DInstalled(const QQmlEngine &engine)
       box2dInstalled = (component != nullptr);
     */
     bool box2dInstalled = false;
-    for (const QString &folder: engine.importPathList()) {
+    const QStringList importPathList = engine.importPathList();
+    for (const QString &folder: importPathList) {
         if (QDir(folder).entryList().contains(QStringLiteral("Box2D.2.0"))) {
             if (QDir(folder + "/Box2D.2.0").entryList().contains("qmldir")) {
                 qDebug() << "Found box2d in " << folder;
@@ -253,7 +249,7 @@ void ApplicationInfo::setBox2DInstalled(const QQmlEngine &engine)
         }
     }
     m_isBox2DInstalled = box2dInstalled;
-    emit isBox2DInstalledChanged();
+    Q_EMIT isBox2DInstalledChanged();
 }
 
 // return the shortest possible locale name for the given locale, describing
