@@ -14,11 +14,8 @@
 #include "DownloadManager.h"
 
 #include <qmath.h>
-#include <QUrl>
-#include <QUrlQuery>
 #include <QGuiApplication>
 #include <QScreen>
-#include <QLocale>
 #include <QRect>
 
 #include <QtQml>
@@ -206,8 +203,10 @@ ApplicationSettings::~ApplicationSettings()
     m_config.setValue(PREVIOUS_WIDTH_KEY, m_previousWidth);
     m_config.setValue(VIRTUALKEYBOARD_KEY, m_isVirtualKeyboard);
     m_config.setValue(ENABLE_AUTOMATIC_DOWNLOADS, m_isAutomaticDownloadsEnabled);
-    m_config.setValue(FILTER_LEVEL_MIN, m_filterLevelMin);
-    m_config.setValue(FILTER_LEVEL_MAX, m_filterLevelMax);
+    if (!m_filterLevelOverridedByCommandLineOption) {
+        m_config.setValue(FILTER_LEVEL_MIN, m_filterLevelMin);
+        m_config.setValue(FILTER_LEVEL_MAX, m_filterLevelMax);
+    }
     m_config.setValue(KIOSK_KEY, m_isKioskMode);
     m_config.setValue(SECTION_VISIBLE, m_sectionVisible);
     m_config.setValue(EXIT_CONFIRMATION, m_exitConfirmation);
@@ -337,7 +336,7 @@ void ApplicationSettings::setIsAutomaticDownloadsEnabled(const bool newIsAutomat
 {
     if (ApplicationInfo::isDownloadAllowed()) {
         m_isAutomaticDownloadsEnabled = newIsAutomaticDownloadsEnabled;
-        emit automaticDownloadsEnabledChanged();
+        Q_EMIT automaticDownloadsEnabledChanged();
     }
 }
 void ApplicationSettings::notifyAutomaticDownloadsEnabledChanged()
@@ -348,14 +347,18 @@ void ApplicationSettings::notifyAutomaticDownloadsEnabledChanged()
 
 void ApplicationSettings::notifyFilterLevelMinChanged()
 {
-    updateValueInConfig(GENERAL_GROUP_KEY, FILTER_LEVEL_MIN, m_filterLevelMin);
     qDebug() << "filterLevelMin set to: " << m_filterLevelMin;
+    if (!m_filterLevelOverridedByCommandLineOption) {
+        updateValueInConfig(GENERAL_GROUP_KEY, FILTER_LEVEL_MIN, m_filterLevelMin);
+    }
 }
 
 void ApplicationSettings::notifyFilterLevelMaxChanged()
 {
-    updateValueInConfig(GENERAL_GROUP_KEY, FILTER_LEVEL_MAX, m_filterLevelMax);
     qDebug() << "filterLevelMax set to: " << m_filterLevelMax;
+    if (!m_filterLevelOverridedByCommandLineOption) {
+        updateValueInConfig(GENERAL_GROUP_KEY, FILTER_LEVEL_MAX, m_filterLevelMax);
+    }
 }
 
 void ApplicationSettings::notifyKioskModeChanged()
@@ -454,7 +457,7 @@ QVariantMap ApplicationSettings::loadActivityConfiguration(const QString &activi
 {
     qDebug() << "load configuration for:" << activity;
     m_config.beginGroup(activity);
-    QStringList keys = m_config.childKeys();
+    const QStringList keys = m_config.childKeys();
     QVariantMap data;
     for (const QString &key: keys) {
         data[key] = m_config.value(key);
@@ -478,7 +481,9 @@ bool ApplicationSettings::isFavorite(const QString &activity)
 
 void ApplicationSettings::setCurrentLevels(const QString &activity, const QStringList &level, bool sync)
 {
-    updateValueInConfig(LEVELS_GROUP_KEY, activity, level, sync);
+    if (!m_filterLevelOverridedByCommandLineOption) {
+        updateValueInConfig(LEVELS_GROUP_KEY, activity, level, sync);
+    }
 }
 
 QStringList ApplicationSettings::currentLevels(const QString &activity)
