@@ -253,6 +253,19 @@ function resolveLocale(localeToSet) {
     }
 }
 
+function convertNumberToLocaleString(decimalNumber, locale = GCompris.ApplicationInfo.localeShort, format = 'f', precision = 0) {
+    // Special case for Arabic, we still want to use Arabic numerals, not Eastern Arabic numerals
+    // For now, we consider dot separated numbers for Arabic
+    var localeToConvertTo = (locale.startsWith("ar") ? "he" : locale);
+    return decimalNumber.toLocaleString(Qt.locale(localeToConvertTo), format, precision);
+}
+
+function convertNumberToLocaleCurrencyString(number, locale) {
+    // Special case for Arabic, we still want to use Arabic numerals, not Eastern Arabic numerals but we want to keep the Arabic currency
+    var localeToConvertTo = (locale.startsWith("ar") ? "he" : locale);
+    return number.toLocaleCurrencyString(Qt.locale(localeToConvertTo), Qt.locale(locale).currencySymbol(Qml.Locale.CurrencySymbol));
+}
+
 /**
  * Function that returns the best cell size for a grid of a given
  * width and height and a number of items.
