@@ -20,7 +20,7 @@
 class CoreFileTest : public QObject
 {
     Q_OBJECT
-private slots:
+private Q_SLOTS:
     void cleanup();
     void FileExistsTest();
     void ReadWriteErrorsTest();
